"""
Configuration constants for energy self-consumption module

This module centralizes all configuration constants used throughout
the energy self-consumption module to improve maintainability and
reduce magic numbers/strings.
"""

from odoo import _

# Configuration state constants
from odoo.addons.energy_communities.config import (
    STATE_ACTIVE,
    STATE_CANCELLED,
    STATE_CHANGE,
    STATE_DRAFT,
    STATE_INACTIVE,
    STATE_LABELS,
    STATE_NONE,
    STATE_PROCESS,
    STATE_VALIDATED,
)

# Invoicing mode constants
SELFCONSUMPTION_INVOICING_MODE_NONE = STATE_NONE
SELFCONSUMPTION_INVOICING_MODE_POWER_ACQUIRED = "power_acquired"
SELFCONSUMPTION_INVOICING_MODE_ENERGY_DELIVERED = "energy_delivered"
SELFCONSUMPTION_INVOICING_MODE_ENERGY_CUSTOM = "energy_custom"

SELFCONSUMPTION_INVOICING_MODE_LABELS = {
    SELFCONSUMPTION_INVOICING_MODE_NONE: STATE_LABELS[
        SELFCONSUMPTION_INVOICING_MODE_NONE
    ],
    SELFCONSUMPTION_INVOICING_MODE_POWER_ACQUIRED: _("Power Acquired"),
    SELFCONSUMPTION_INVOICING_MODE_ENERGY_DELIVERED: _("Energy Delivered"),
    SELFCONSUMPTION_INVOICING_MODE_ENERGY_CUSTOM: _("Energy Delivered Custom"),
}

SELFCONSUMPTION_INVOICING_MODE_VALUES = [
    (
        SELFCONSUMPTION_INVOICING_MODE_POWER_ACQUIRED,
        SELFCONSUMPTION_INVOICING_MODE_LABELS[
            SELFCONSUMPTION_INVOICING_MODE_POWER_ACQUIRED
        ],
    ),
    (
        SELFCONSUMPTION_INVOICING_MODE_ENERGY_DELIVERED,
        SELFCONSUMPTION_INVOICING_MODE_LABELS[
            SELFCONSUMPTION_INVOICING_MODE_ENERGY_DELIVERED
        ],
    ),
    (
        SELFCONSUMPTION_INVOICING_MODE_ENERGY_CUSTOM,
        SELFCONSUMPTION_INVOICING_MODE_LABELS[
            SELFCONSUMPTION_INVOICING_MODE_ENERGY_CUSTOM
        ],
    ),
]

SELFCONSUMPTION_DEFAULT_INVOICING_MODE = SELFCONSUMPTION_INVOICING_MODE_POWER_ACQUIRED

# Product template references
SELFCONSUMPTION_PRODUCT_REFS = {
    SELFCONSUMPTION_INVOICING_MODE_POWER_ACQUIRED: {
        "template": "energy_selfconsumption.product_product_power_acquired_product_template",
        "pack": "energy_selfconsumption.product_product_power_acquired_product_pack_template",
    },
    SELFCONSUMPTION_INVOICING_MODE_ENERGY_DELIVERED: {
        "template": "energy_selfconsumption.product_product_energy_delivered_product_template",
        "pack": "energy_selfconsumption.product_product_energy_delivered_product_pack_template",
    },
    SELFCONSUMPTION_INVOICING_MODE_ENERGY_CUSTOM: {
        "template": "energy_selfconsumption.product_product_energy_custom_product_template",
        "pack": "energy_selfconsumption.product_product_energy_custom_product_pack_template",
    },
}

# STATES
SELFCONSUMPTION_CONF_STATE_ACTIVE = STATE_ACTIVE
SELFCONSUMPTION_CONF_STATE_INACTIVE = STATE_INACTIVE

SELFCONSUMPTION_CONF_STATE_VALUES = [
    (
        SELFCONSUMPTION_CONF_STATE_ACTIVE,
        STATE_LABELS[SELFCONSUMPTION_CONF_STATE_ACTIVE],
    ),
    (
        SELFCONSUMPTION_CONF_STATE_INACTIVE,
        STATE_LABELS[SELFCONSUMPTION_CONF_STATE_INACTIVE],
    ),
]
SELFCONSUMPTION_CONF_STATE_DEFAULT_VALUE = SELFCONSUMPTION_CONF_STATE_INACTIVE

# Inscription state constants
INSCRIPTION_STATE_ACTIVE = STATE_ACTIVE
INSCRIPTION_STATE_INACTIVE = STATE_INACTIVE
INSCRIPTION_STATE_CHANGE = STATE_CHANGE
INSCRIPTION_STATE_CANCELLED = STATE_CANCELLED

INSCRIPTION_STATE_VALUES = [
    (INSCRIPTION_STATE_ACTIVE, STATE_LABELS[INSCRIPTION_STATE_ACTIVE]),
    (INSCRIPTION_STATE_INACTIVE, STATE_LABELS[INSCRIPTION_STATE_INACTIVE]),
    (INSCRIPTION_STATE_CHANGE, STATE_LABELS[INSCRIPTION_STATE_CHANGE]),
    (INSCRIPTION_STATE_CANCELLED, STATE_LABELS[INSCRIPTION_STATE_CANCELLED]),
]
INSCRIPTION_STATE_DEFAULT_VALUE = INSCRIPTION_STATE_INACTIVE

# Distribution table state constants
DISTRIBUTION_STATE_DRAFT = STATE_DRAFT
DISTRIBUTION_STATE_PROCESS = STATE_PROCESS
DISTRIBUTION_STATE_VALIDATED = STATE_VALIDATED
DISTRIBUTION_STATE_ACTIVE = STATE_ACTIVE
DISTRIBUTION_STATE_CANCELLED = STATE_CANCELLED

DISTRIBUTION_STATE_VALUES = [
    (DISTRIBUTION_STATE_DRAFT, STATE_LABELS[DISTRIBUTION_STATE_DRAFT]),
    (DISTRIBUTION_STATE_VALIDATED, STATE_LABELS[DISTRIBUTION_STATE_VALIDATED]),
    (DISTRIBUTION_STATE_PROCESS, STATE_LABELS[DISTRIBUTION_STATE_PROCESS]),
    (DISTRIBUTION_STATE_ACTIVE, STATE_LABELS[DISTRIBUTION_STATE_ACTIVE]),
    (DISTRIBUTION_STATE_CANCELLED, STATE_LABELS[DISTRIBUTION_STATE_CANCELLED]),
]
DISTRIBUTION_STATE_DEFAULT_VALUE = DISTRIBUTION_STATE_DRAFT

# Distribution table type constants
DISTRIBUTION_TYPE_FIXED = "fixed"
DISTRIBUTION_TYPE_HOURLY = "hourly"

DISTRIBUTION_TYPE_VALUES = [
    (DISTRIBUTION_TYPE_FIXED, _("Fixed")),
    (DISTRIBUTION_TYPE_HOURLY, _("Variable hourly")),
]

DISTRIBUTION_TYPE_DEFAULT_VALUE = DISTRIBUTION_TYPE_FIXED

# CAU and CIL validation constants
CAU_LENGTH_24 = 24
CAU_LENGTH_26 = 26
CIL_LENGTH_23 = 23
CIL_LENGTH_25 = 25
CUPS_LENGTH_20 = 20
CUPS_LENGTH_22 = 22
CAU_SEPARATOR = "A"
LAST_DIGITS_COUNT = 3

# Tariff constants
TARIFF_2_0TD = "2.0TD"
TARIFF_3_0TD = "3.0TD"
TARIFF_6_1TD = "6.1TD"
TARIFF_6_2TD = "6.2TD"
TARIFF_6_3TD = "6.3TD"
TARIFF_6_4TD = "6.4TD"

TARIFF_POWER_LIMITS = {
    TARIFF_2_0TD: 15,  # kW
    TARIFF_3_0TD: 300,  # kW
}

# Power validation constants
MIN_POWER_VALUE = 0.0
MAX_POWER_VALUE = 10000.0  # 10 MW

# CSV processing constants
CSV_DELIMITER = ","
CSV_QUOTE_CHAR = '"'
CSV_FILE_EXTENSION = "csv"
DEFAULT_ENCODING = "utf-8"

# Default participation options for new projects
DEFAULT_PARTICIPATIONS = [
    {"name": "1.0 kW", "quantity": 1.0},
    {"name": "2.0 kW", "quantity": 2.0},
    {"name": "3.0 kW", "quantity": 3.0},
    {"name": "5.0 kW", "quantity": 5.0},
]
SELFCONSUMPTION_DEFAULT_PARTICIPATIONS = [
    {"name": "0,5 kW", "quantity": 0.5},
    {"name": "1,0 kW", "quantity": 1.0},
    {"name": "1,5 kW", "quantity": 1.5},
    {"name": "2,0 kW", "quantity": 2.0},
]
